@@ -2,3 +2,8 @@
 # © Copyright 2021-2022 Zapata Computing Inc.
 ################################################################################
 from .simulator import CirqSimulator
+
+try:
+    from .qsim_simulator import QSimSimulator
+except ModuleNotFoundError:
+    pass
